# -*- coding: utf-8 -*-
from setuphelpers import *


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    api_url = "https://sourceforge.net/projects/dvdstyler/best_release.json"
    bin_contains = "DVDStyler"
    bin_name_dict = {
        "windows-x64": bin_contains + "-%s-win64.exe",
        "windows-x86": bin_contains + "-%s-win32.exe",
        "macos-all": bin_contains + "-%s_1-MacOSX.dmg",
        "linux-all": bin_contains + "-%s.tar.bz2",
    }

    # Getting latest version information from official sources
    print("API used is: %s" % api_url)
    json_load = wgets(api_url, proxies=proxies, as_json=True)
    for download in json_load["platform_releases"]:
        if ".exe" in json_load["platform_releases"][download]["filename"]:
            version = json_load["platform_releases"][download]["filename"].split("-")[1]
    latest_bin = bin_name_dict[control.target_os + "-" + ensure_list(control.architecture)[0]] % version
    download_url = "https://sourceforge.net/projects/dvdstyler/files/dvdstyler/%s/%s/download" % (version, latest_bin)

    # Downloading latest binaries
    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL is: %s" % download_url)
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Deleting outdated binaries
    remove_outdated_binaries(latest_bin)

    # Changing version of the package
    if Version(version, 4) > Version(control.get_software_version(), 4):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Validating update-package-sources
    return package_updated
